==> haskell-ansi-wl-pprint-0.6.8.2-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ansi-wl-pprint
version: 0.6.8.2
id: ansi-wl-pprint-0.6.8.2-LQZDE7SKgje91HGB8abfY4
key: ansi-wl-pprint-0.6.8.2-LQZDE7SKgje91HGB8abfY4
license: BSD-3-Clause
maintainer: Edward Kmett <ekmett@gmail.com>
author: Daan Leijen, Max Bolingbroke
homepage: http://github.com/ekmett/ansi-wl-pprint
synopsis: The Wadler/Leijen Pretty Printer for colored ANSI terminal output
description:
    This is a pretty printing library based on Wadler'\''s paper ["A Prettier Printer"](https://homepages.inf.ed.ac.uk/wadler/papers/prettier/prettier.pdf). It has been enhanced with support for ANSI terminal colored output using the [ansi-terminal](https://hackage.haskell.org/package/ansi-terminal) package.
category: User Interfaces, Text
abi: d46a34a69558ad25fb56e0bfd9741e31
exposed: True
exposed-modules:
    Text.PrettyPrint.ANSI.Leijen Text.PrettyPrint.ANSI.Leijen.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/ansi-wl-pprint-0.6.8.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/ansi-wl-pprint-0.6.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/ansi-wl-pprint-0.6.8.2
hs-libraries: HSansi-wl-pprint-0.6.8.2-LQZDE7SKgje91HGB8abfY4
depends:
    ansi-terminal-0.8.1-72nCTUZRZdJG8ztHzhbgjc base-4.11.1.0
abi-depends: ansi-terminal-0.8.1-72nCTUZRZdJG8ztHzhbgjc=ac560d64fefa05d8067fac44b9aaa9de
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-ansi-wl-pprint/html/ansi-wl-pprint.haddock
haddock-html: /usr/share/doc/haskell-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ansi-wl-pprint-0.6.8.2-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ansi-wl-pprint
version: 0.6.8.2
id: ansi-wl-pprint-0.6.8.2-IorYGC2IHKLB6bH0iJmQIJ
key: ansi-wl-pprint-0.6.8.2-IorYGC2IHKLB6bH0iJmQIJ
license: BSD-3-Clause
maintainer: Edward Kmett <ekmett@gmail.com>
author: Daan Leijen, Max Bolingbroke
homepage: http://github.com/ekmett/ansi-wl-pprint
synopsis: The Wadler/Leijen Pretty Printer for colored ANSI terminal output
description:
    This is a pretty printing library based on Wadler'\''s paper ["A Prettier Printer"](https://homepages.inf.ed.ac.uk/wadler/papers/prettier/prettier.pdf). It has been enhanced with support for ANSI terminal colored output using the [ansi-terminal](https://hackage.haskell.org/package/ansi-terminal) package.
category: User Interfaces, Text
abi: 3cfa710aa3040fa4acf91ecff38087a2
exposed: True
exposed-modules:
    Text.PrettyPrint.ANSI.Leijen Text.PrettyPrint.ANSI.Leijen.Internal
import-dirs: /usr/lib/ghc-8.6.1/site-local/ansi-wl-pprint-0.6.8.2
library-dirs: /usr/lib/ghc-8.6.1/site-local/ansi-wl-pprint-0.6.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/ansi-wl-pprint-0.6.8.2
hs-libraries: HSansi-wl-pprint-0.6.8.2-IorYGC2IHKLB6bH0iJmQIJ
depends:
    ansi-terminal-0.8.2-8WQDEUM7Kz3DSmwgHomKFP base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-ansi-wl-pprint/html/ansi-wl-pprint.haddock
haddock-html: /usr/share/doc/haskell-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
